summaryrefslogtreecommitdiffstats
path: root/pym/_emerge/create_depgraph_params.py
diff options
context:
space:
mode:
authorZac Medico <zmedico@gentoo.org>2012-08-29 13:23:22 -0700
committerZac Medico <zmedico@gentoo.org>2012-08-29 13:23:22 -0700
commit78ba7f0d3a3a2defdf9807ef2e8138965490a2fc (patch)
tree10a549acf3569d3104291e38927cd8318318da09 /pym/_emerge/create_depgraph_params.py
parent9f14ed80e65a18da06e0834961ea032e3e830319 (diff)
downloadportage-78ba7f0d3a3a2defdf9807ef2e8138965490a2fc.tar.gz
portage-78ba7f0d3a3a2defdf9807ef2e8138965490a2fc.tar.bz2
portage-78ba7f0d3a3a2defdf9807ef2e8138965490a2fc.zip
Rename slot-abi stuff to refer to slot-operator.
This makes it consistent with the language in the PMS eapi-5 branch: http://git.overlays.gentoo.org/gitweb/?p=proj/pms.git;a=commit;h=5d6749ac9e5ddc5b1daaad7737b65fa81c6ece47
Diffstat (limited to 'pym/_emerge/create_depgraph_params.py')
-rw-r--r--pym/_emerge/create_depgraph_params.py20
1 files changed, 10 insertions, 10 deletions
diff --git a/pym/_emerge/create_depgraph_params.py b/pym/_emerge/create_depgraph_params.py
index 2838e93c3..98a76460c 100644
--- a/pym/_emerge/create_depgraph_params.py
+++ b/pym/_emerge/create_depgraph_params.py
@@ -15,11 +15,11 @@ def create_depgraph_params(myopts, myaction):
# complete: completely account for all known dependencies
# remove: build graph for use in removing packages
# rebuilt_binaries: replace installed packages with rebuilt binaries
# rebuild_if_new_slot_abi: rebuild or reinstall packages when
# SLOT/ABI := operator dependencies can be satisfied by a newer
# SLOT/ABI, so that older packages slots will become eligible for
# removal by the --depclean action as soon as possible
# ignore_built_slot_abi_deps: ignore the SLOT/ABI := operator parts
# of dependencies that have been recorded when packages where built
myparams = {"recurse" : True}
@@ -27,9 +27,9 @@ def create_depgraph_params(myopts, myaction):
if bdeps is not None:
myparams["bdeps"] = bdeps
- ignore_built_slot_abi_deps = myopts.get("--ignore-built-slot-abi-deps")
- if ignore_built_slot_abi_deps is not None:
- myparams["ignore_built_slot_abi_deps"] = ignore_built_slot_abi_deps
+ ignore_built_slot_operator_deps = myopts.get("--ignore-built-slot-operator-deps")
+ if ignore_built_slot_operator_deps is not None:
+ myparams["ignore_built_slot_operator_deps"] = ignore_built_slot_operator_deps
dynamic_deps = myopts.get("--dynamic-deps")
if dynamic_deps is not None:
@@ -41,9 +41,9 @@ def create_depgraph_params(myopts, myaction):
myparams["selective"] = True
return myparams
- rebuild_if_new_slot_abi = myopts.get('--rebuild-if-new-slot-abi')
- if rebuild_if_new_slot_abi is not None:
- myparams['rebuild_if_new_slot_abi'] = rebuild_if_new_slot_abi
+ rebuild_if_new_slot = myopts.get('--rebuild-if-new-slot')
+ if rebuild_if_new_slot is not None:
+ myparams['rebuild_if_new_slot'] = rebuild_if_new_slot
if "--update" in myopts or \
"--newuse" in myopts or \
@@ -15,11 +15,11 @@ def create_depgraph_params(myopts, myaction):
# remove: build graph for use in removing packages
# rebuilt_binaries: replace installed packages with rebuilt binaries
- # rebuild_if_new_slot_abi: rebuild or reinstall packages when
- # SLOT/ABI := operator dependencies can be satisfied by a newer
- # SLOT/ABI, so that older packages slots will become eligible for
+ # rebuild_if_new_slot: rebuild or reinstall packages when
+ # slot/sub-slot := operator dependencies can be satisfied by a newer
+ # slot/sub-slot, so that older packages slots will become eligible for
# removal by the --depclean action as soon as possible
@@ -15,11 +15,11 @@ def create_depgraph_params(myopts, myaction):
# removal by the --depclean action as soon as possible
- # ignore_built_slot_abi_deps: ignore the SLOT/ABI := operator parts
+ # ignore_built_slot_operator_deps: ignore the slot/sub-slot := operator parts
# of dependencies that have been recorded when packages where built
myparams = {"recurse" : True}